@@ -21,12 +21,10 @@
 #include <KStandardAction>
 #include <KScoreDialog>
 #include <KToggleAction>
-#include <KConfigDialog>
-#include <KMessageBox>
 #include <KLocalizedString>
 #include <KStandardGameAction>
-#include <KGameRenderer>
 #include <KgThemeSelector>
+#include <KGameRenderer>
 
 KLinesMainWindow::KLinesMainWindow()
 {
